{#
Copyright (C) 2023 CERN.

Invenio App RDM is free software; you can redistribute it and/or modify it
under the terms of the MIT License; see LICENSE file for more details.
#}

{% extends "invenio_administration/search.html" %}


{% block javascript %}
  {{ super() }}
  {{ webpack['invenio-users-moderation-administration.js'] }}
{% endblock %}
