{#
# This file is part of Invenio.
# Copyright (C) 2022-2024 CERN.
# Copyright (C) 2024 KTH Royal Institute of Technology.
#
# Invenio is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
#}
{% extends config.PAGES_BASE_TEMPLATE %}

{% set title = page.title %}
{% block page_body %}
<div class="ui container rel-mt-2">
    <div class="row">
          <div class="col-xs-12 rich-input-content">
            <h1>{{ page.title|safe }}</h1>
            {% block content %}{{ page.content|safe }}{% endblock %}
        </div>
    </div>
</div>
{% endblock %}

