{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2022 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}
{% set title = invenio_request.title %}
{% extends "invenio_requests/details/index.html" %}
{% from "invenio_requests/macros/request_header.html" import invitation_request_header %}

{% set active_community_header_menu_item = 'members' %}
{% set active_members_menu_item = 'invitations' %}

{% block request_header %}
  {% set back_button_url = url_for("invenio_communities.invitations", pid_value=invenio_request.created_by.community) %}
  {{
    invitation_request_header(
      back_button_url=back_button_url,
      back_button_text=_("Back to invitations"),
      request=invenio_request
    )
  }}
{% endblock %}


{% block settings_body %}
  <div class="sixteen wide mobile sixteen wide tablet thirteen wide computer column right floated">
    {% block request_body %}
      {{ super() }}
    {% endblock request_body %}
  </div>
{% endblock %}

{% block page_body %}
  {{ super.super() }}
{% endblock page_body %}
